@@ -180,16 +180,23 @@ on_user_delete_clicked (GtkButton *button, gpointer user_data)
 	GtkTreePath *path;
 	GList *list, *elem;
 
+	/* No need to prompt if not allowed */
+	if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->users_config))
+		return;
+
 	list = elem = table_get_row_references (TABLE_USERS, &model);
 
 	while (elem) {
 		path = gtk_tree_row_reference_get_path (elem->data);
+
 		user_delete (model, path);
 
 		gtk_tree_path_free (path);
 		elem = elem->next;
 	}
 
+	users_table_select_first ();
+
 	g_list_foreach (list, (GFunc) gtk_tree_row_reference_free, NULL);
 	g_list_free (list);
 }
@@ -241,35 +248,6 @@ select_main_group (OobsUser *user)
 		gtk_combo_box_set_active (GTK_COMBO_BOX (combo), -1);
 }
 
-/* Retrieve the NO_PASSWD_LOGIN_GROUP.
- * Don't forget to unref the returned group when done. */
-static OobsGroup *
-get_no_passwd_login_group ()
-{
-	OobsGroupsConfig *config;
-	OobsList *groups_list;
-	OobsListIter iter;
-	OobsGroup *group;
-	gboolean valid;
-	const gchar *group_name;
-
-	config = OOBS_GROUPS_CONFIG (GST_USERS_TOOL (tool)->groups_config);
-	groups_list = oobs_groups_config_get_groups (config);
-	valid = oobs_list_get_iter_first (groups_list, &iter);
-
-	while (valid) {
-		group = OOBS_GROUP (oobs_list_get (groups_list, &iter));
-		group_name = oobs_group_get_name (group);
-
-		if (group_name && strcmp (NO_PASSWD_LOGIN_GROUP, group_name) == 0)
-			return group;
-
-		valid = oobs_list_iter_next (groups_list, &iter);
-	}
-
-	return NULL;
-}
-
 static void
 set_login_length (GtkWidget *entry)
 {
@@ -468,63 +446,6 @@ check_shell (gchar **primary_text, gchar **secondary_text, gpointer data)
 	}
 }
 
-static gboolean
-check_password (OobsUser *user)
-{
-	GtkWidget *dialog;
-	GtkWidget *widget;
-	const gchar *password, *confirmation;
-	char *primary_text = NULL;
-	char *secondary_text;
-	int len;
-
-	widget = gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual");
-
-	/* manual password? */
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget))) {
-		widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd1");
-		password = gtk_entry_get_text (GTK_ENTRY (widget));
-
-		widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd2");
-		confirmation = gtk_entry_get_text (GTK_ENTRY (widget));
-	} else {
-		widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_random_passwd");
-		password = confirmation = gtk_entry_get_text (GTK_ENTRY (widget));
-	}
-
-	len = strlen (password);
-
-	/* empty password, accept but don't change it */
-	if (len == 0) {
-		return TRUE;
-	}
-	else if (len < 6) {
-		primary_text = _("Password is too short");
-		secondary_text = _("User passwords must be longer than 6 characters and preferably "
-		                   "formed by numbers, letters and special characters.");
-	} else if (strcmp (password, confirmation) != 0) {
-		primary_text = _("Password confirmation is not correct");
-		secondary_text = _("Check that you have provided the same password in both text fields.");
-	}
-
-	if (primary_text) {
-		dialog = gtk_message_dialog_new (GTK_WINDOW (tool->main_dialog),
-		                                 GTK_DIALOG_MODAL,
-		                                 GTK_MESSAGE_ERROR,
-		                                 GTK_BUTTONS_CLOSE,
-		                                 "%s", primary_text);
-
-		gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
-		                                            "%s", secondary_text);
-
-		gtk_dialog_run (GTK_DIALOG (dialog));
-		gtk_widget_destroy (dialog);
-		return FALSE;
-	}
-
-	return TRUE;
-}
-
 /*
  * Check that current user is not removing himself from the admin group: warn if it's the case.
  * Also, if selected user is the only admin left, we directly show an error dialog.
@@ -913,6 +834,7 @@ on_user_new (GtkButton *button, gpointer user_data)
 	GtkWidget *user_login;
 	GtkWidget *login_entry;
 	GtkWidget *notice_image;
+	GtkWidget *encrypted_home;
 	GtkTreeModel *model;
 	GtkTreePath *user_path;
 	OobsUser *user;
@@ -920,12 +842,20 @@ on_user_new (GtkButton *button, gpointer user_data)
 	GstUserProfile *profile;
 	OobsUsersConfig *users_config;
 	OobsResult result;
+	gboolean encrypt;
+
+	/* Before going further, check for authorizations, authenticating if needed */
+	if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->users_config))
+		return;
 
 	user_new_dialog = gst_dialog_get_widget (tool->main_dialog, "user_new_dialog");
 	user_name = gst_dialog_get_widget (tool->main_dialog, "user_new_name");
 	user_login = gst_dialog_get_widget (tool->main_dialog, "user_new_login");
 	login_entry = gtk_bin_get_child (GTK_BIN (user_login));
 	notice_image = gst_dialog_get_widget (tool->main_dialog, "user_new_notice_image");
+	encrypted_home = gst_dialog_get_widget (tool->main_dialog, "user_new_encrypted_home");
+
+	users_config = OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config);
 
 	/* clear any text, colors or icon left */
 	gtk_entry_set_text (GTK_ENTRY (user_name), "");
@@ -934,6 +864,10 @@ on_user_new (GtkButton *button, gpointer user_data)
 	gtk_combo_box_set_active (GTK_COMBO_BOX (user_login), -1);
 	on_user_new_login_changed (GTK_COMBO_BOX (user_login), NULL);
 
+	/* Show the encrypt home check box if supported */
+	if (oobs_users_config_get_encrypted_home_support (users_config))
+	    gtk_widget_show (encrypted_home);
+
 	gtk_window_set_focus (GTK_WINDOW (user_new_dialog), user_name);
 
 	set_login_length (login_entry);
@@ -954,8 +888,10 @@ on_user_new (GtkButton *button, gpointer user_data)
 	   following the system configuration. */
 	login = gtk_combo_box_get_active_text (GTK_COMBO_BOX (user_login));
 	fullname = gtk_entry_get_text (GTK_ENTRY (user_name));
+	encrypt = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (encrypted_home));
 	user = oobs_user_new (login);
 	oobs_user_set_full_name (user, fullname);
+	oobs_user_set_encrypted_home (user, encrypt);
 
 	g_return_if_fail (user != NULL);
 
@@ -963,8 +899,6 @@ on_user_new (GtkButton *button, gpointer user_data)
 	profile = gst_user_profiles_get_default_profile (GST_USERS_TOOL (tool)->profiles);
 	gst_user_profiles_apply (GST_USERS_TOOL (tool)->profiles, profile, user, TRUE);
 
-	users_config = OOBS_USERS_CONFIG (GST_USERS_TOOL (tool)->users_config);
-
 	/* Commit both user and groups config because of possible memberships
 	 * added by the profile. Avoid showing the new user or trying to commit
 	 * group changes if the user has not been created. */
@@ -1034,15 +968,32 @@ on_edit_user_name (GtkButton *button, gpointer user_data)
 	GtkWidget *user_name_entry;
 	GtkWidget *face_image;
 	GtkWidget *name_label;
+	GtkWidget *user_settings_real_name;
 	OobsUser *user;
 	const char *fullname;
+	gboolean is_self;
+
+	user = users_table_get_current ();
+
+	/* Before going further, check for authorizations, authenticating if needed */
+	is_self = oobs_self_config_is_user_self (OOBS_SELF_CONFIG (GST_USERS_TOOL (tool)->self_config),
+	                                         user);
+
+	/* Authenticate as self when changing self user, as admin for all other users */
+	if (is_self) {
+		if (!gst_tool_authenticate (tool, GST_USERS_TOOL (tool)->self_config))
+			return;
+	}
+	else if (!gst_tool_authenticate (tool, OOBS_OBJECT (user)))
+		return;
 
 	user_name_dialog = gst_dialog_get_widget (tool->main_dialog, "user_name_dialog");
 	user_name_entry = gst_dialog_get_widget (tool->main_dialog, "user_name_entry");
 	face_image = gst_dialog_get_widget (tool->main_dialog, "user_name_face");
 	name_label = gst_dialog_get_widget (tool->main_dialog, "user_name_name");
+	user_settings_real_name = gst_dialog_get_widget (tool->main_dialog,
+	                                                 "user_settings_real_name");
 
-	user = users_table_get_current ();
 	fullname = oobs_user_get_full_name (user);
 	gtk_entry_set_text (GTK_ENTRY (user_name_entry), fullname);
 	gtk_editable_select_region (GTK_EDITABLE (user_name_entry), 0, -1);
@@ -1056,109 +1007,15 @@ on_edit_user_name (GtkButton *button, gpointer user_data)
 
 		fullname = gtk_entry_get_text (GTK_ENTRY (user_name_entry));
 		oobs_user_set_full_name (user, fullname);
-		gst_tool_commit (tool, OOBS_OBJECT (user));
-	}
 
-	g_object_unref (user);
-}
-
-/*
- * Callback for edit_user_name_button: run the dialog to change the user's
- * password and apply changes if needed.
- */
-void
-on_edit_user_passwd (GtkButton *button, gpointer user_data)
-{
-	int response;
-	GtkWidget *user_passwd_dialog;
-	GtkWidget *face_image;
-	GtkWidget *name_label;
-	GtkWidget *manual_toggle;
-	GtkWidget *passwd_entry;
-	GtkWidget *nocheck_toggle;
-	OobsUser *user;
-	OobsGroup *no_passwd_login_group;
-	const char *passwd;
-
-	user_passwd_dialog = gst_dialog_get_widget (tool->main_dialog, "user_passwd_dialog");
-	face_image = gst_dialog_get_widget (tool->main_dialog, "user_passwd_face");
-	name_label = gst_dialog_get_widget (tool->main_dialog, "user_passwd_name");
-
-	user = users_table_get_current ();
-
-	/* set manual password */
-	manual_toggle = gst_dialog_get_widget (tool->main_dialog, "user_passwd_manual");
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (manual_toggle), TRUE);
-
-	/* clear entries */
-	passwd_entry = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd1");
-	set_entry_text (passwd_entry, NULL);
-
-	passwd_entry = gst_dialog_get_widget (tool->main_dialog, "user_settings_passwd2");
-	set_entry_text (passwd_entry, NULL);
-
-	/* set option to skip password check at login */
-	nocheck_toggle = gst_dialog_get_widget (tool->main_dialog, "user_passwd_no_check");
-	no_passwd_login_group = get_no_passwd_login_group ();
-	/* root should not be allowed to login without password,
-	 * and we disable the feature if the group does not exist */
-	if (oobs_user_is_root (user) || no_passwd_login_group == NULL) {
-		gtk_widget_set_sensitive (nocheck_toggle, FALSE);
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (nocheck_toggle),
-		                              FALSE);
-	}
-	else {
-		gst_dialog_try_set_sensitive (tool->main_dialog, nocheck_toggle, TRUE);
-		if (oobs_user_is_in_group (user, no_passwd_login_group))
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (nocheck_toggle),
-			                              TRUE);
+		if (is_self)
+			gst_tool_commit (tool, GST_USERS_TOOL (tool)->self_config);
 		else
-			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (nocheck_toggle),
-			                              FALSE);
+			gst_tool_commit (tool, OOBS_OBJECT (user));
+
+		gtk_label_set_text (GTK_LABEL (user_settings_real_name), fullname);
+		users_table_update_current ();
 	}
-	if (no_passwd_login_group)
-		g_object_unref (no_passwd_login_group);
-
-
-	do {
-		response = run_edit_dialog (GTK_DIALOG (user_passwd_dialog),
-		                            GTK_IMAGE (face_image), GTK_LABEL (name_label));
-	} while (response == GTK_RESPONSE_OK && !check_password (user));
-
-	if (response != GTK_RESPONSE_OK){
-		g_object_unref (user);
-		return;
-	}
-
-	/* set manual or random password if needed */
-	if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (manual_toggle)))
-		passwd_entry = gst_dialog_get_widget (tool->main_dialog,
-		                                      "user_settings_passwd1");
-	else
-		passwd_entry = gst_dialog_get_widget (tool->main_dialog,
-		                                      "user_settings_random_passwd");
-
-	passwd = gtk_entry_get_text (GTK_ENTRY (passwd_entry));
-
-	/* empty password means: don't change it */
-	if (strlen (passwd) > 0)
-		oobs_user_set_password (user, passwd);
-
-	/* check whether user is allowed to login without password */
-	no_passwd_login_group = get_no_passwd_login_group ();
-	if (!oobs_user_is_root (user) && no_passwd_login_group != NULL) {
-		if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (nocheck_toggle)))
-			oobs_group_add_user (no_passwd_login_group, user);
-		else
-			oobs_group_remove_user (no_passwd_login_group, user);
-	}
-	if (no_passwd_login_group)
-		g_object_unref (no_passwd_login_group);
-
-	/* commit both user and groups config
-	 * because of the no_passwd_login_group membership */
-	if (gst_tool_commit (tool, OOBS_OBJECT (user)) == OOBS_RESULT_OK)
-		gst_tool_commit (tool, GST_USERS_TOOL (tool)->groups_config);
 
 	g_object_unref (user);
 }
@@ -1185,6 +1042,12 @@ on_edit_user_profile (GtkButton *button, gpointer user_data)
 	OobsUser *user;
 	GstUserProfile *profile;
 
+	user = users_table_get_current ();
+
+	/* Before going further, check for authorizations, authenticating if needed */
+	if (!gst_tool_authenticate (tool, OOBS_OBJECT (user)))
+		return;
+
 	user_profile_dialog = gst_dialog_get_widget (tool->main_dialog, "user_profile_dialog");
 	face_image = gst_dialog_get_widget (tool->main_dialog, "user_profile_face");
 	name_label = gst_dialog_get_widget (tool->main_dialog, "user_profile_name");
@@ -1192,8 +1055,6 @@ on_edit_user_profile (GtkButton *button, gpointer user_data)
 	custom_radio = gst_dialog_get_widget (tool->main_dialog, "user_profile_custom");
 	custom_label = gst_dialog_get_widget (tool->main_dialog, "user_profile_custom_label");
 
-	user = users_table_get_current ();
-
 	/* select the profile that matches the user settings, if any */
 	profile = gst_user_profiles_get_for_user (GST_USERS_TOOL (tool)->profiles,
 	                                          user, FALSE);
@@ -1262,12 +1123,16 @@ on_edit_user_advanced (GtkButton *button, gpointer user_data)
 		NULL
 	};
 
+	user = users_table_get_current ();
+
+	/* Before going further, check for authorizations, authenticating if needed */
+	if (!gst_tool_authenticate (tool, OOBS_OBJECT (user)))
+		return;
+
 	user_advanced_dialog = gst_dialog_get_widget (tool->main_dialog, "user_advanced_dialog");
 	face_image = gst_dialog_get_widget (tool->main_dialog, "user_advanced_face");
 	name_label = gst_dialog_get_widget (tool->main_dialog, "user_advanced_name");
 
-	user = users_table_get_current ();
-
 
 	/* set various settings */
 	widget = gst_dialog_get_widget (tool->main_dialog, "user_settings_room_number");
