@@ -29,11 +29,11 @@
 #include "users-tool.h"
 #include "user-profiles.h"
 
-#define NO_PASSWD_LOGIN_GROUP "nopasswdlogin"
+#define ADMIN_GROUP "admin"
 
 gboolean        user_delete                      (GtkTreeModel *model,
 						  GtkTreePath *path);
-void	        user_settings_set	         (OobsUser *user);
+void            user_settings_show               (OobsUser *user);
 gint            user_settings_dialog_run         (GtkWidget *dialog);
 
 OobsUser *      user_settings_dialog_get_data    (GtkWidget *dialog);
@@ -43,6 +43,8 @@ uid_t           user_settings_find_new_uid       (gint uid_min,
 gboolean        user_settings_is_user_in_group   (OobsUser  *user,
                                                   OobsGroup *group);
 
+gboolean        user_settings_check_revoke_admin_rights ();
+
 void            on_user_new                      (GtkButton *button, gpointer user_data);
 
 
